// functions.c
// this file is about the use of functions in C
#include <stdio.h>

/*
"For the functions we write ourselves, we use the term 'definition.'
 The general form of a function definition in C is as follows:

[Return type] <function name> ([parameters]) { ... ... }"
*/

// ==========prototypes
//power(int number, int pwr);
int power(int number, int pwr);
void message();
void message2(void);

void functions()
{
	int n = 10;
	int pw = 5;
	printf("\n-----functions\n");
	// "Functions can only be called from within defined functions.
	// Functions cannot be called from outside blocks."
	int result = power(n,pw);
	printf("%d. power of %d is %d\n", pw, n, result);
	message(1.0);
	message2();
}

// message(1.0); X Functions cannot be called from outside blocks."

// ==========function implementations

//power(int number, int pwr)
// if  there is no return type indicated by default it is int
// as if it is->   int power(int number, int pwr) ...
// but to be on the side of good programming put the return type
int power (int number, int pwr)
{
	int result = 1;
	int i;
	for (i=0; i<pwr; i++)
		result = result * number;
	return result;
}

void message()
{
	printf("\n|=====================void message()===============================|\n");
	printf(  "|this function have the parameter list like ... ()                 |\n");
	printf(  "|but it can be called like message(1.0). why?                      |\n");
	printf(  "|in C empty parameter list means parameter checking is disabled.   |\n");
	printf(  "|So, whether it is message() or message(1.0) does not matter !     |\n");
	printf(  "|==================================================================|\n");
}

void message2(void)
{
	printf("\n|=====================void message2(void)==========================|\n");
	printf(  "|this function have the parameter list like ... (void)             |\n");
	printf(  "|it can be called like message2(1.0).                              |\n");
	printf(  "|in C void in parameter list means function takes no argument      |\n");
	printf(  "|message2(1.0) results in \"too many arguments to function\" error   |\n");
	printf(  "|==================================================================|\n");

}

//NOTES***************************************//

/*
"For the functions we write ourselves, we use the term 'definition.'
 The general form of a function definition in C is as follows:

[Return type] <function name> ([parameters]) { ... ... }"
*/

/*

Return Values of Functions

The value that a function sends back to the calling function at the end of its execution is called the function's return value.
Not every function is required to produce a return value. The return values of functions can be used for different purposes:

	1 - Some functions are designed to obtain a single value. They return the obtained value to the calling function as the return value. For example:

y = pow(2, 3);

The pow function is a standard C function. It calculates the power of the number specified by the first parameter raised to the power specified by the second parameter, and then sends the calculated value back to the calling function as the return value. In the above example, the third power of 2 is calculated by this function and the result is assigned to the variable y.

	2 - Some functions' return values provide information about the success of the operations performed during the function's execution. In other words, the return values of these functions are used for testing purposes. Return values explain whether the desired operation was successful or not. For example:

p = malloc(200);

In this case, the programmer wants to allocate a block of memory 200 bytes long. However, they must also test whether this operation was successful. Immediately after the malloc call, the value of the p variable will be checked to determine the success of the operation. Therefore, the return value of the malloc function indicates whether the operation has been successfully completed.

	3 - Some functions test the arguments passed to them based on certain criteria. The return value they produce indicates the result of the test. For example:

if (isspace(ch)) {
    ...
}
Here, the isspace function tests whether the character passed as an argument is a whitespace character. If it is a whitespace character, isspace will return a non-zero value, and if it is not, it will return 0. Based on the return value, different operations can be performed in the calling function.

	4 - Some functions perform a specific task and, in addition, produce a return value that completes their purpose. For example:

x = printf("Hello World\n");
In this case, the printf function is used to print "Hello World" to the screen. However, it also returns the number of characters printed as a return value.

	5 - Sometimes return values are not needed. For instance, a function designed solely to clear the screen does not need a return value.

clrscr();
The clrscr function only clears the screen, so it does not need a return value.

There are also types for function return values. The return values of functions can be of any type, and their types are specified when the function is declared.
*/
