
// if_statements.c
// this file is about the use of conditional statements and character test functions in C
// check https://tr.wikipedia.org/wiki/ASCII for ASCII characters


#include <stdio.h>
#include <ctype.h>

int _is_upper(char ch);
// isupper, islower, isdigit, isalpha is the standard C versions of these functions with the same use.
// these are sample functions we typed here
int _is_lower(char ch);
int _is_digit(char ch);
int _is_alpha(char ch);

void if_statements()
{
	printf("\n-----if_statements\n");

	int x = 1;
	int m;

	m = (x > 5) ? 1 : 0;
	// ? : conditional operator
	printf("m = %d\n", m);

	// same as
	if (x>5)
		m = 1;
	else
		m = 0;

	printf("m = %d\n\n", m);

	char ch = 'Q';

	if (ch >= 'a' && ch <= 'z')
		printf("character %c is a lowercase latter\n", ch);
	else
		printf("character %c is not a lowercase latter\n", ch);

	ch = 'a';
		if (ch >= 'a' && ch <= 'z')
		printf("character %c is a lowercase latter\n", ch);
	else
		printf("character %c is not a lowercase latter\n", ch);

	if (10)
		printf("always true\n"); // True Statement is executed

	if (0) //zero value lead us to the false statements of the if
		;
	else
		printf("always false\n"); // False Statement is executed

	// bool flag = false; bool is a C++ type, not in C.
	// Thus, we cannot input exact boolean values for if conditions

	int flag = 0;
	if (flag != 0 )
		printf ("flag is not zero\n");
	else if (flag == 0 ) // just else will be enough
		printf ("flag is zero\n");

	flag = 5;
	if (flag)
		printf ("flag is different than zero\n");
		// numbers other than zero lead us to the true statements of the if

	flag = -5;
	if (flag)
		printf ("flag is different than zero\n");
		// numbers other than zero lead us to the true statements of the if

	//if -5, Not true. Always use parentheses for conditions
	if (-5)  // numbers other than zero lead us to the true statements of the if
		printf("this is a true statement\n");


	//===================================================================
	//is-functions
	//===================================================================

	char array1[6] = {'a', 'A', '1', '+', '@', '\0'};
	// the last one is just Null character to terminate any char array.

	int i = 0;
	for (i = 0; i<=4; i++)
	{
		if (_is_upper(array1[i]))
			printf("the character %c is an uppercase letter\n", array1[i]);
		else if (_is_lower(array1[i]))
			printf("the character %c is a lowercase letter\n", array1[i]);
		else if (_is_digit(array1[i]))
			printf("the character %c is a digit\n", array1[i]);
		else
			printf("the character %c is not an alphanumeric char.\n", array1[i]);
	}


	// isspace and isprint are standard C functions
	printf("\n");
	for (i = 0; i<=127; i++)
		if (isprint(i)!=0)
				printf("ASCII Code %d,  the character %c is printable\n", i, i);


	/* space characters
		' '	space
		'\n'	newline
		'\t'	horizontal tab
		'\v'	vertical tab
		'\f'	form feed
		'\r'	Carriage return
	*/

	printf("\n");

	char array2[7] = {' ', '\n', '\t', '\v', '\f','\r', '\0'};
	// the last one is just Null character to terminate any char array.

	for (i = 0; i<=5; i++)
		if (isspace(array2[i]))
			printf("ASCII Code %d,  the character %c is a space character\n",array2[i],  array2[i]);

	// only space character is printable
	// thus we have a reasonable display only for space
}


int _is_upper(char ch)
{
	if (ch >= 'A' && ch <= 'Z') //[65...90]
		return 1;
	else
		return 0;
}

int _is_lower(char ch)
{
	if (ch >= 'a' && ch <= 'a') //[97...102]
		return 1;
	else
		return 0;

}

int _is_alpha(char ch)
// checks if the character is an alphabetic character
// a-z, A-Z
{
	if ((ch >= 'a' && ch <= 'a') || (ch >= 'A' && ch <= 'Z') )
		return 1;
	else
		return 0;

}

int _is_digit(char ch) ////[30..39]
// checks if the character is a digit
// a-z, A-Z
{
	if (ch >= '0' && ch <= '9')
		return 1;
	else
		return 0;

}

//NOTES***************************************//

/*  standard character test functions in C | #include <ctype.h> for these

isalpha: True if it is an alphabetic character, False otherwise.
isupper: True if it is an uppercase letter, False otherwise.
islower: True if it is a lowercase letter, False otherwise.
isdigit: True if it is a numeric character, False otherwise.
isxdigit: True if it is a character representing a hexadecimal number, False otherwise.
isalnum: True if it is an alphabetic or numeric character, False otherwise.
isspace: True if it is a whitespace character (space, carriage return, newline, vertical tab, form feed), False otherwise.
ispunct: True if it is a punctuation character (any character that is not a control, alphanumeric, or whitespace character), False otherwise.
isprint: True if it is a printable character (including space), False otherwise.
isgraph: True if it is a visible character (excluding space), False otherwise.
iscntrl: True if it is a control character or delete character (first 32 characters or character number 127), False otherwise.
isascii: True if it is one of the first 128 characters in the standard ASCII table, False otherwise.

*/
